/*
	************************************************
	folderHorizon service.js
	* Editor & Status service
	* Vars in global_service.tpl
	* Not loaded in release
	************************************************
*/

/****************************
Editor
*/
var text = document.getElementById('text'),
	errorService = document.getElementById('errorService'),
	editorWrapper = document.getElementById('editorWrapper'),
	placeholder = '<i class="editor-placeholder">double-click to write text</i>',
	errorMessage = 'Editor service does not respond. Is it running?';

// Double-click to open editor
text.addEventListener("dblclick", function () {
	this.classList.add('hidden');
	editorWrapper.classList.remove('hidden');
});

// Create editor
ClassicEditor.create(document.querySelector('#editor'), {
	language: 'en',
	link: {
		addTargetToExternalLinks: true,
		decorators: [
			{
				mode: 'manual',
				label: 'Open New Tab',
				attributes: {
					target: '_blank'
				}
			}
		]
	}
}).then(editor => {

	window.editor = editor;

	// Close button
	document.getElementById('editorClose').addEventListener('click', function () {
		text.innerHTML = (editor.editing.view.getDomRoot().innerText.trim() !== '') ? editor.getData() : placeholder;
		editorWrapper.classList.add('hidden');
		text.classList.remove('hidden');
	});

	// Save button
	document.querySelector('#editorSave').addEventListener('click', () => {
		editorWrapper.classList.add('hidden');
		editorService((editor.editing.view.getDomRoot().innerText !== '') ? editor.getData() : '');
	});

	// XMLHttpRequest
	function editorService(html) {
		var xhr = new XMLHttpRequest();
		xhr.timeout = 3000;
		xhr.open('POST', serviceUrl + '/editor', true); // ...
		xhr.onreadystatechange = function () {
			if (xhr.readyState === 4) {
				if (xhr.status === 200) {
					if (xhr.responseText) {
						var res = JSON.parse(xhr.responseText);
						if (res.text == '') {
							text.innerHTML = placeholder;
							editor.setData('');
						} else {
							text.innerHTML = res.text;
							editor.setData(res.text);
						}
						text.classList.remove('hidden');
					}
				} else {
					errorService.innerHTML = errorMessage;
				}
			}
		};
		xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
		xhr.send(JSON.stringify({ text: html, file: editorTextFile })); // ...
	}

	editorService('[LoadFile]');

}).catch(error => {
	console.log(error);
});

/****************************
Status service
*/
var idAlertChanges = 'alertChanges',
	idModalLoader = 'modalLoader',
	loading = false;

setInterval(function () {
	statusService();
}, 2000);

// XMLHttpRequest
function statusService() {
	var xhr = new XMLHttpRequest();
	xhr.timeout = 1500;
	xhr.open('POST', serviceUrl + '/status', true); // ...
	xhr.onreadystatechange = function () {
		if (xhr.readyState === 4) {
			if (xhr.status === 200) {
				if (xhr.responseText) {
					var res = JSON.parse(xhr.responseText);
					if (res.status == 'changed') {
						alertChanges();
					} else if (res.status == 'building') {
						modalLoader();
					} else if (res.status == 'reload') {
						location.reload();
					} else if (res.status == 'home') {
						window.location.replace(statusBackRef + 'index.html');
					}
				}
			} else if (!loading) {
				modalLoader();
				document.getElementById(idModalLoader).textContent = '* folderHorizon service has been stopped *';
			}
		}
	};
	xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded; charset=UTF-8');
	xhr.send(JSON.stringify({ ref: statusBackRef, status: statusIndexFile })); // ...
}

// Alert on changes
function alertChanges() {
	var el = document.createElement('div');
	el.id = idAlertChanges;
	el.style.position = 'fixed';
	el.style.zIndex = 1;
	el.style.bottom = 0;
	el.style.left = 0;
	el.style.width = '100%';
	el.style.backgroundColor = '#FFA500';
	el.style.color = '#000000';
	el.style.fontSize = '14px';
	el.style.fontWeight = 500;
	el.style.textAlign = 'center';
	el.style.opacity = 0.9;
	el.textContent = '* press Enter on terminal to update changes *';
	document.body.prepend(el);
}

// Modal loader on building changes
function modalLoader() {
	if (document.getElementById(idAlertChanges) != null) {
		document.getElementById(idAlertChanges).remove();
	}
	var el = document.createElement('div');
	el.id = idModalLoader;
	el.style.position = 'fixed';
	el.style.zIndex = 2;
	el.style.top = 0;
	el.style.left = 0;
	el.style.opacity = 0.7;
	el.style.width = '100%';
	el.style.height = '100vh';
	el.style.backgroundColor = '#FFFFFF';
	el.style.backgroundImage = "url('" + statusLoaderImg + "')"; // ...
	el.style.backgroundRepeat = 'no-repeat';
	el.style.backgroundPosition = 'center';
	el.style.backgroundSize = "64px";
	el.style.paddingTop = '54vh';
	el.style.color = '#000000';
	el.style.fontSize = '14px';
	el.style.fontWeight = 700;
	el.style.textAlign = 'center';
	el.textContent = '* please do not modify the archive folder while updating *';
	document.body.prepend(el);
	loading = true;
}
